<?php
//关闭错误提示
ini_set('display_errors', 0);
// read config.ini
if (($config = parse_ini_file("config.ini", true)) == false) {
    // uh-oh, failed ot read ini file
    $status = "Missing or corrupt configuration file!";
} else {
    // config.ini read successfully, let's break it up to sections
    $globalConfig = $config['global'];
    unset($config['global']);
    $pcConfigs = $config;
    // get config of selected PC
    $pcSelected = isset($_GET['pc']) ? $_GET['pc'] : array_key_first($config);
    $pcConfig = $pcConfigs[$pcSelected];
    // ping PC
    $online = fsockopen($pcConfig['ip'], $pcConfig['pingPort'], $errno, $errstr, $globalConfig["pingTimeout"]);
    // check if we want to wake or just fetching page
    if (isset($_POST['wake'])) {
        // check password if needed
        if ((isset($_POST['pwd']) && $pcConfig['password'] == $_POST['pwd']) ||
            $pcConfig['password'] == ""
        ) {
            // password ok/not needed, lets send WOL
            $result = sendMagicPacket($pcConfig['ip'], $pcConfig['mac']);
            $status = $result ? 'Magic packet sent to ' . $pcConfig['pcName'] : 'Failed to send WOL packet';
        } else $status = 'Incorrect password';
    }
}

function sendMagicPacket($ip, $mac, $port = 9)
{
    $addr_byte = explode('-', $mac);
    $hw_addr = '';
    for ($a = 0; $a < 6; $a++) $hw_addr .= chr(hexdec($addr_byte[$a]));
    $msg = chr(255) . chr(255) . chr(255) . chr(255) . chr(255) . chr(255);
    for ($a = 1; $a <= 16; $a++) $msg .= $hw_addr;
    // Send data packets via UDP
    $s = socket_create(AF_INET, SOCK_DGRAM, SOL_UDP);

    if ($s == false) {
        return false; // socket_create Execution failed
    }

    $set_opt = @socket_set_option($s, 1, 6, TRUE);

    if ($set_opt < 0) {
        return false; // socket_set_option Execution failed
    }

    $sendto = @socket_sendto($s, $msg, strlen($msg), 0, $ip, $port);

    if ($sendto) {
        socket_close($s);
        return true; // magic packet Sent successfully!
    }

    return false; // magic packet Failed to send!
}

?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta http-equiv="content-type" content="text/html;charset=utf-8"/>
    <!-- Bootstrap 5.0.2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet"
          integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
    <!-- Bootstrap 5.0.2 JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js"
            integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM"
            crossorigin="anonymous"></script>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta charset="utf-8">
    <title>⏰ Wake PC</title>
</head>

<body>
<div class="container-fluid">
<div class="row" style="margin:auto; margin-top: 2em; justify-content: center;">
    <div class="col-lg-3 col-md-4 col-xs-6">
        <h4 class="card-title mb-3">Wake PC</h4>
        <form action="" method="post">
            <select id="pc-select" class="form-select mb-3" name="pc" onchange="pcSelected()">
                <?php
                foreach ($pcConfigs as $key => $value) {
                    echo '<option value="' . $key . '" ' . ($key === $pcSelected ? "selected" : "") . '>' . $value["pcName"] . '</option>';
                }
                ?>
            </select>
            <?php
            if ($pcConfig['password'] != "") {
                echo '
						<div class="form-group mb-3" >
							<label for="pwd">Password</label>
							<input type="password" class="form-control" id="pwd" name="pwd" placeholder="Password">
						</div>
						';
            }
            ?>
            <?php
            if ($online) {
                echo '<p class="text-center" style="color:green; cursor: pointer;" onclick="reload()">⬤ Online</p>';
            } else {
                echo '<p class="text-center" style="color:red; cursor: pointer;" onclick="reload()">❌ Offline</p>';
            }
            ?>
            <div class="d-grid mb-3">
                <button class="btn btn-primary btn-block" type="submit" id="wake-btn" name="wake"
                        value="wake"><?= $globalConfig['wakeButtonText'] ?></button>
            </div>
        </form>
        <div class="text-center"><?= $status ?></div>
    </div>
</div>
</div>
</body>

</html>
<script>
    function pcSelected() {
        selected = document.getElementById("pc-select").value;
        var url = new URL(window.location);
        url.searchParams.set('pc', selected);
        window.open(url, "_self");
    }

    function reload() {
        window.location.reload();
    }
</script>